[gtk+] Better mark GtkAlignment as deprecated



commit c104c6443624f2064e0fcef5ab33548c29f4bac5
Author: Sébastien Wilmet <swilmet gnome org>
Date:   Sat Sep 13 17:16:04 2014 +0200

    Better mark GtkAlignment as deprecated
    
    - Move the class to the Deprecated section.
    - Warning at the bottom of the class description.
    - A missing property was not marked as deprecated.
    - Update doc of gtk_container_set_border_width() to not mention
      GtkAlignment.
    
    https://bugzilla.gnome.org/show_bug.cgi?id=736622

 docs/reference/gtk/gtk-docs.sgml |    2 +-
 gtk/deprecated/gtkalignment.c    |    9 +++++----
 gtk/gtkcontainer.c               |    7 +++----
 3 files changed, 9 insertions(+), 9 deletions(-)
---
diff --git a/docs/reference/gtk/gtk-docs.sgml b/docs/reference/gtk/gtk-docs.sgml
index dfe76c0..2e00bae 100644
--- a/docs/reference/gtk/gtk-docs.sgml
+++ b/docs/reference/gtk/gtk-docs.sgml
@@ -79,7 +79,6 @@
       <xi:include href="xml/gtkactionbar.xml" />
       <xi:include href="xml/gtkheaderbar.xml" />
       <xi:include href="xml/gtkoverlay.xml" />
-      <xi:include href="xml/gtkalignment.xml" />
       <xi:include href="xml/gtkbbox.xml" />
       <xi:include href="xml/gtkpaned.xml" />
       <xi:include href="xml/gtklayout.xml" />
@@ -340,6 +339,7 @@
       <xi:include href="xml/gtkarrow.xml" />
       <xi:include href="xml/gtkstatusicon.xml" />
       <xi:include href="xml/gtkthemingengine.xml" />
+      <xi:include href="xml/gtkalignment.xml" />
     </chapter>
 
   </part>
diff --git a/gtk/gtkcontainer.c b/gtk/gtkcontainer.c
index 05c1bc0..0394a99 100644
--- a/gtk/gtkcontainer.c
+++ b/gtk/gtkcontainer.c
@@ -1498,10 +1498,9 @@ _gtk_container_set_border_width_set (GtkContainer *container,
  * around the outside of the container. The only exception to this is
  * #GtkWindow; because toplevel windows can’t leave space outside,
  * they leave the space inside. The border is added on all sides of
- * the container. To add space to only one side, one approach is to
- * create a #GtkAlignment widget, call gtk_widget_set_size_request()
- * to give it a size, and place it on the side of the container as
- * a spacer.
+ * the container. To add space to only one side, use a specific
+ * #GtkWidget:margin property on the child widget, for example
+ * #GtkWidget:margin-top.
  **/
 void
 gtk_container_set_border_width (GtkContainer *container,


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/gtk/deprecated/gtkalignment.c b/gtk/deprecated/gtkalignment.c
index 0b32553..54079f5 100644
--- a/gtk/deprecated/gtkalignment.c
+++ b/gtk/deprecated/gtkalignment.c
@@ -40,9 +40,10 @@
  * Of course, if the scale settings are both set to 1, the alignment settings
  * have no effect.
  *
  * Note that the desired effect can in most cases be achieved by using the
  * #GtkWidget:halign, #GtkWidget:valign and #GtkWidget:margin properties
  * on the child widget, so #GtkAlignment should not be used in new code.
  */
 
 #include "config.h"
@@ -143,7 +144,7 @@ gtk_alignment_class_init (GtkAlignmentClass *class)
                                                       0.0,
                                                       1.0,
                                                       0.5,
-                                                      GTK_PARAM_READWRITE));
+                                                      GTK_PARAM_READWRITE|G_PARAM_DEPRECATED));
    
   g_object_class_install_property (gobject_class,
                                    PROP_YALIGN,
@@ -40,9 +40,10 @@
  * have no effect.
  *
- * Note that the desired effect can in most cases be achieved by using the
- * #GtkWidget:halign, #GtkWidget:valign and #GtkWidget:margin properties
- * on the child widget, so #GtkAlignment should not be used in new code.
+ * GtkAlignment has been deprecated in 3.14 and should not be used in
+ * newly-written code. The desired effect can be achieved by using the
+ * #GtkWidget:halign, #GtkWidget:valign and #GtkWidget:margin properties on the
+ * child widget.
  */
 